use Module::Build;
my $build = Module::Build->new(
    module_name => 'Tie::Hash::Constant',
    license     => 'perl',
    build_requires => {
        'Test::More' => 0,
    },
    create_makefile_pl => 'traditional',
   )->create_build_script;
